Changelog
^^^^^^^^^

Version 0.1.2
-------------
* add type hints
* more documentation

Version 0.1.1
-------------
* more documentation
* minor fixes and additions

Version 0.1.0
-------------
* Intial release
